@@ -156,8 +156,8 @@ class UserDefinedFactory(PipeFactory):
             if not isinstance(filter, tvtk.Object):
                 try:
                     filter = getattr(tvtk, filter)
-                except AttributeError, e:
-                    raise 'Filter %s unknown to TVTK' % filter 
+                except AttributeError:
+                    raise Exception('Filter %s unknown to TVTK' % filter)
                 kwargs['filter'] = filter()
                 self._target.filter = kwargs['filter']
                 self._target.setup_filter()
