@@ -4,7 +4,7 @@ Data sources classes and their associated functions for mlab.
 
 # Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
 #         Prabhu Ramachandran
-# Copyright (c) 2007-2009, Enthought, Inc. 
+# Copyright (c) 2007-2010, Enthought, Inc. 
 # License: BSD Style.
 
 import operator
@@ -82,6 +82,8 @@ class MlabSource(HasTraits):
             self.dataset.modified()
             md = self.m_data
             if md is not None:
+                if hasattr(md, '_assign_attribute'):
+                    md._assign_attribute.update()
                 md.data_changed = True
 
     def set(self, trait_change_notify=True, **traits):
@@ -499,7 +501,12 @@ class MLineSource(MlabSource):
             pd = tvtk.PolyData()
         else:
             pd = self.dataset
-        pd.set(points=points, lines=lines)
+        # Avoid lines refering to non existing points: First set the 
+        # lines to None, then set the points, then set the lines
+        # refering to the new points.
+        pd.set(lines=None)
+        pd.set(points=points)
+        pd.set(lines=lines)
 
         if scalars is not None and len(scalars) > 0:
             assert len(x) == len(scalars)
