@@ -34,7 +34,6 @@ Behaviour:
 """
 
 # import usual libraries
-import math, os, sys
 import wx
 import vtk
 
@@ -357,7 +356,7 @@ class wxVTKRenderWindowInteractor(baseClass):
                 
                 # we now have 0xdeadbeef
                 # VTK wants it as: _deadbeef_void_p (pre-SWIG-1.3 style)
-                d = '_%s_%s' % (d[2:], 'void_p')
+                d = '_%s_%s\0' % (d[2:], 'void_p')
 
         return d
 
