@@ -427,7 +427,11 @@ class VTKMethodParser:
         """
         # These ignored ones are really not state methods.
         ignore = ['SetUpdateExtentToWholeExtent',
-                  'SetDataExtentToWholeExtent']
+                  'SetDataExtentToWholeExtent',
+                  'SetOutputSpacingToDefault', # In vtkImageReslice.
+                  'SetOutputOriginToDefault', # In vtkImageReslice
+                  'SetOutputExtentToDefault' # In vtkImageReslice
+                  ]
         meths = methods[:]
         sm = self.state_meths
         for method in meths[:]:
