@@ -29,6 +29,6 @@ mlab.figure(size=(400, 300))
 mlab.surf(julia, colormap='gist_earth', warp_scale='auto', vmax=1.5)
 
 # A view into the "Canyon"
-mlab.view(65, 27, 390, [ 6.,  -47,  169])
+mlab.view(65, 27, 322, [ 30.,  -13.7,  136])
 mlab.show()
 
