@@ -8,6 +8,7 @@
 import os.path
 import sys
 import logging
+import traceback
 from optparse import OptionParser
 
 # Enthought library imports
@@ -363,7 +364,23 @@ class TestCase(Mayavi):
         run the test."""
 
         # Calls the users test code.
-        self.do()
+        try:
+            self.do()
+        except Exception, e:
+            # To mimic behavior of unittest.
+            sys.stderr.write('\nfailures=1\n')
+            type, value, tb = sys.exc_info()
+            info = traceback.extract_tb(tb)
+            filename, lineno, function, text = info[-1] # last line only
+            exc_msg = "%s\nIn %s:%d\n%s: %s (in %s)" %\
+                      ('Exception', filename, lineno, type.__name__, str(value),
+                       function)
+            sys.stderr.write(exc_msg + '\n')
+            # Log the message.
+            logger.exception(exc_msg)
+            if not self.interact:
+                sys.exit(1)
+
         if not self.interact:
             if self.standalone:
                 # Close all existing viewers.
